@@ -6,7 +6,7 @@ Redis::JobQueue::Job - Object interface for creating and manipulating jobs
 
 =head1 VERSION
 
-This documentation refers to C<Redis::JobQueue::Job> version 1.07
+This documentation refers to C<Redis::JobQueue::Job> version 1.09
 
 =cut
 
@@ -18,7 +18,7 @@ use warnings;
 
 # ENVIRONMENT ------------------------------------------------------------------
 
-our $VERSION = '1.07';
+our $VERSION = '1.09';
 
 #-- load the modules -----------------------------------------------------------
 
@@ -614,7 +614,8 @@ sub job_attributes {
 #-- private methods ------------------------------------------------------------
 
 sub _build_data {
-    return \'';
+    my $empty_data = q{};
+    return \$empty_data;
 }
 
 sub _build_modified {
